j\_chess\_lib.client.match package
==================================

Submodules
----------

j\_chess\_lib.client.match.Game module
--------------------------------------

.. automodule:: j_chess_lib.client.match.Game
   :members:
   :undoc-members:
   :show-inheritance:

j\_chess\_lib.client.match.Match module
---------------------------------------

.. automodule:: j_chess_lib.client.match.Match
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: j_chess_lib.client.match
   :members:
   :undoc-members:
   :show-inheritance:
